<!-- start_examination.html -->
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Start Examination</title>
</head>
<body>
    <h1>Hello World</h1>
</body>
</html>
